@@ -811,7 +811,7 @@ class GraphNode(object):
                  "rev",
                  "shape",
                  "toplines",
-                 "troubles",
+                 "instabilities",
                  "wdparent",
                  "x"]
 
@@ -843,7 +843,7 @@ class GraphNode(object):
         self.rev = ctx.rev()
         self.hidden = ctx.hidden()
         self.obsolete = ctx.obsolete()
-        self.troubles = ctx.troubles()
+        self.instabilities = ctx.instabilities()
         self.shape = shape
         self.x = xposition
         self.bottomlines = lines
@@ -876,7 +876,7 @@ class PatchGraphNode(object):
         self.wdparent = False
         self.toplines = []
         self.bottomlines = []
-        self.troubles = ()
+        self.instabilities = ()
         self.x = 0
 
     @property
@@ -915,6 +915,11 @@ class Graph(object):
             return self.nodes[-1]
         return self.nodes[idx]
 
+    def getrevstate(self, idx):
+        """Return (rev, isunapplied) of the node at the specified row"""
+        n = self[idx]
+        return n.rev, False
+
     def __len__(self):
         # len(graph) is the number of actually built graph nodes
         return len(self.nodes)
@@ -1014,6 +1019,12 @@ class GraphWithMq(object):
             return PatchGraphNode(self._patchnames[row])
         return self.graph[row - len(self._patchnames)]
 
+    def getrevstate(self, row):
+        """Return (rev, isunapplied) of the node at the specified row"""
+        if row < len(self._patchnames):
+            return self._patchnames[row], True
+        return self.graph.getrevstate(row - len(self._patchnames))
+
     def index(self, rev):
         """Get row number for specified revision"""
         if isinstance(rev, str):
