@@ -5,32 +5,58 @@
 # This software may be used and distributed according to the terms
 # of the GNU General Public License, incorporated herein by reference.
 
+from __future__ import absolute_import
+
 import os
 import time
 
-from mercurial import commands, error
+from .qtcore import (
+    QSettings,
+    Qt,
+    pyqtSlot,
+)
+from .qtgui import (
+    QAction,
+    QComboBox,
+    QDialog,
+    QFrame,
+    QHBoxLayout,
+    QKeySequence,
+    QPushButton,
+    QSplitter,
+    QToolBar,
+    QVBoxLayout,
+)
 
-from tortoisehg.util import hglib
-from tortoisehg.util.patchctx import patchctx
-from tortoisehg.hgqt.i18n import _
-from tortoisehg.hgqt import qtlib, cmdui, chunks
+from mercurial import (
+    commands,
+    error,
+    util,
+)
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from ..util import hglib
+from ..util.i18n import _
+from ..util.patchctx import patchctx
+from . import (
+    cmdui,
+    chunks,
+    qtlib,
+)
 
 class ShelveDialog(QDialog):
 
     wdir = _('Working Directory')
 
-    def __init__(self, repo, parent=None):
+    def __init__(self, repoagent, parent=None):
         QDialog.__init__(self, parent)
         self.setWindowFlags(Qt.Window)
 
-        self.setWindowIcon(qtlib.geticon('shelve'))
+        self.setWindowIcon(qtlib.geticon('hg-shelve'))
 
-        self.repo = repo
+        self._repoagent = repoagent
         self.shelves = []
         self.patches = []
+        self._patchnames = {}  # path: mq patch name
 
         layout = QVBoxLayout()
         layout.setContentsMargins(2, 2, 2, 2)
@@ -51,15 +77,14 @@ class ShelveDialog(QDialog):
         aframe = QFrame(self.splitter)
         avbox = QVBoxLayout()
         avbox.setSpacing(2)
-        avbox.setMargin(2)
         avbox.setContentsMargins(2, 2, 2, 2)
         aframe.setLayout(avbox)
         ahbox = QHBoxLayout()
         ahbox.setSpacing(2)
-        ahbox.setMargin(2)
         ahbox.setContentsMargins(2, 2, 2, 2)
         avbox.addLayout(ahbox)
         self.comboa = QComboBox(self)
+        self.comboa.setMinimumContentsLength(10)  # allow to cut long content
         self.comboa.currentIndexChanged.connect(self.comboAChanged)
         self.clearShelfButtonA = QPushButton(_('Clear'))
         self.clearShelfButtonA.setToolTip(_('Clear the current shelf file'))
@@ -71,7 +96,7 @@ class ShelveDialog(QDialog):
         ahbox.addWidget(self.clearShelfButtonA)
         ahbox.addWidget(self.delShelfButtonA)
 
-        self.browsea = chunks.ChunksWidget(repo, self, True)
+        self.browsea = chunks.ChunksWidget(self._repoagent, self)
         self.browsea.splitter.splitterMoved.connect(self.linkSplitters)
         self.browsea.linkActivated.connect(self.linkActivated)
         self.browsea.showMessage.connect(self.showMessage)
@@ -80,15 +105,14 @@ class ShelveDialog(QDialog):
         bframe = QFrame(self.splitter)
         bvbox = QVBoxLayout()
         bvbox.setSpacing(2)
-        bvbox.setMargin(2)
         bvbox.setContentsMargins(2, 2, 2, 2)
         bframe.setLayout(bvbox)
         bhbox = QHBoxLayout()
         bhbox.setSpacing(2)
-        bhbox.setMargin(2)
         bhbox.setContentsMargins(2, 2, 2, 2)
         bvbox.addLayout(bhbox)
         self.combob = QComboBox(self)
+        self.combob.setMinimumContentsLength(10)  # allow to cut long content
         self.combob.currentIndexChanged.connect(self.comboBChanged)
         self.clearShelfButtonB = QPushButton(_('Clear'))
         self.clearShelfButtonB.setToolTip(_('Clear the current shelf file'))
@@ -100,17 +124,18 @@ class ShelveDialog(QDialog):
         bhbox.addWidget(self.clearShelfButtonB)
         bhbox.addWidget(self.delShelfButtonB)
 
-        self.browseb = chunks.ChunksWidget(repo, self, True)
+        self.browseb = chunks.ChunksWidget(self._repoagent, self)
         self.browseb.splitter.splitterMoved.connect(self.linkSplitters)
         self.browseb.linkActivated.connect(self.linkActivated)
         self.browseb.showMessage.connect(self.showMessage)
         bvbox.addWidget(self.browseb)
 
         self.lefttbar = QToolBar(_('Left Toolbar'), objectName='lefttbar')
+        self.lefttbar.setIconSize(qtlib.toolBarIconSize())
         self.lefttbar.setStyleSheet(qtlib.tbstylesheet)
         self.tbarhbox.addWidget(self.lefttbar)
         self.deletea = a = QAction(_('Delete selected chunks'), self)
-        self.deletea.triggered.connect(self.browsea.deleteSelectedChunks)
+        self.deletea.triggered.connect(self.deleteChunksA)
         a.setIcon(qtlib.geticon('thg-shelve-delete-left'))
         self.lefttbar.addAction(self.deletea)
         self.allright = a = QAction(_('Move all files right'), self)
@@ -130,6 +155,7 @@ class ShelveDialog(QDialog):
         self.lefttbar.addAction(self.chunksright)
 
         self.rbar = QToolBar(_('Refresh Toolbar'), objectName='rbar')
+        self.rbar.setIconSize(qtlib.toolBarIconSize())
         self.rbar.setStyleSheet(qtlib.tbstylesheet)
         self.tbarhbox.addStretch(1)
         self.tbarhbox.addWidget(self.rbar)
@@ -144,6 +170,7 @@ class ShelveDialog(QDialog):
         self.rbar.addAction(self.actionNew)
 
         self.righttbar = QToolBar(_('Right Toolbar'), objectName='righttbar')
+        self.righttbar.setIconSize(qtlib.toolBarIconSize())
         self.righttbar.setStyleSheet(qtlib.tbstylesheet)
         self.tbarhbox.addStretch(1)
         self.tbarhbox.addWidget(self.righttbar)
@@ -163,7 +190,7 @@ class ShelveDialog(QDialog):
         a.setIcon(qtlib.geticon('thg-shelve-move-left-all'))
         self.righttbar.addAction(self.allleft)
         self.deleteb = a = QAction(_('Delete selected chunks'), self)
-        self.deleteb.triggered.connect(self.browseb.deleteSelectedChunks)
+        self.deleteb.triggered.connect(self.deleteChunksB)
         a.setIcon(qtlib.geticon('thg-shelve-delete-right'))
         self.righttbar.addAction(self.deleteb)
 
@@ -189,11 +216,16 @@ class ShelveDialog(QDialog):
                            'in .hg/Trashcan/'))
 
         self.refreshCombos()
-        repo.repositoryChanged.connect(self.refreshCombos)
+        repoagent.repositoryChanged.connect(self.refreshCombos)
 
-        self.setWindowTitle(_('TortoiseHg Shelve - %s') % repo.displayname)
+        self.setWindowTitle(_('TortoiseHg Shelve - %s')
+                            % repoagent.displayName())
         self.restoreSettings()
 
+    @property
+    def repo(self):
+        return self._repoagent.rawRepo()
+
     @pyqtSlot()
     def moveFileRight(self):
         if self.combob.currentIndex() == -1:
@@ -240,6 +272,23 @@ class ShelveDialog(QDialog):
         if self.browsea.mergeChunks(file, chunks):
             self.browseb.deleteSelectedChunks()
 
+    @pyqtSlot()
+    def deleteChunksA(self):
+        if self.comboa.currentIndex() == 0:
+            msg = _('Delete selected chunks from working copy?')
+        else:
+            f = hglib.tounicode(os.path.basename(self.currentPatchA()))
+            msg = _('Delete selected chunks from shelf file %s?') % f
+        if qtlib.QuestionMsgBox(_('Are you sure?'), msg, parent=self):
+            self.browsea.deleteSelectedChunks()
+
+    @pyqtSlot()
+    def deleteChunksB(self):
+        f = hglib.tounicode(os.path.basename(self.currentPatchB()))
+        msg = _('Delete selected chunks from shelf file %s?') % f
+        if qtlib.QuestionMsgBox(_('Are you sure?'), msg, parent=self):
+            self.browseb.deleteSelectedChunks()
+
     @pyqtSlot()
     def newShelfPressed(self):
         self.newShelf(True)
@@ -255,15 +304,20 @@ class ShelveDialog(QDialog):
             if not ok:
                 return
             shelve = hglib.fromunicode(name)
-            invalids = (':', '#', '/', '\\', '<', '>', '|')
+            invalids = (':', '#', '/', '\\')
             bads = [c for c in shelve if c in invalids]
             if bads:
                 qtlib.ErrorMsgBox(_('Bad filename'),
-                                  _('A shelf name cannot contain :#/\\<>|'))
+                                  _('A shelf name cannot contain %s')
+                                  % ''.join(bads))
+                return
+            badmsg = util.checkosfilename(shelve)
+            if badmsg:
+                qtlib.ErrorMsgBox(_('Bad filename'), hglib.tounicode(badmsg))
                 return
         try:
             fn = os.path.join('shelves', shelve)
-            shelfpath = self.repo.join(fn)
+            shelfpath = self.repo.vfs.join(fn)
             if os.path.exists(shelfpath):
                 qtlib.ErrorMsgBox(_('File already exists'),
                                   _('A shelf file of that name already exists'))
@@ -375,7 +429,7 @@ class ShelveDialog(QDialog):
     def refreshCombos(self):
         shelvea, shelveb = self.currentPatchA(), self.currentPatchB()
 
-        # Note that thgshelves returns the shelve list ordered from newest to 
+        # Note that thgshelves returns the shelve list ordered from newest to
         # oldest
         shelves = self.repo.thgshelves()
         disp = [_('Shelf: %s') % hglib.tounicode(s) for s in shelves]
@@ -386,6 +440,7 @@ class ShelveDialog(QDialog):
         # store fully qualified paths
         self.shelves = [os.path.join(self.repo.shelfdir, s) for s in shelves]
         self.patches = [self.repo.mq.join(p) for p in patches]
+        self._patchnames = dict(zip(self.patches, patches))
 
         self.comboRefreshInProgress = True
         self.comboa.clear()
@@ -424,24 +479,39 @@ class ShelveDialog(QDialog):
     def comboAChanged(self, index):
         if self.comboRefreshInProgress:
             return
+        assert index >= 0  # side A should always have "Working Directory"
         if index == 0:
             rev = None
             self.delShelfButtonA.setEnabled(False)
             self.clearShelfButtonA.setEnabled(True)
         else:
             rev = self.currentPatchA()
+            rev = self._patchnames.get(rev, rev)
             self.delShelfButtonA.setEnabled(index <= len(self.shelves))
             self.clearShelfButtonA.setEnabled(index <= len(self.shelves))
         self.browsea.setContext(self.repo.changectx(rev))
+        self._deselectSamePatch(self.combob)
 
     @pyqtSlot(int)
     def comboBChanged(self, index):
         if self.comboRefreshInProgress:
             return
         rev = self.currentPatchB()
-        self.delShelfButtonB.setEnabled(index < len(self.shelves))
-        self.clearShelfButtonB.setEnabled(index < len(self.shelves))
+        rev = self._patchnames.get(rev, rev)
+        self.delShelfButtonB.setEnabled(0 <= index < len(self.shelves))
+        self.clearShelfButtonB.setEnabled(0 <= index < len(self.shelves))
         self.browseb.setContext(self.repo.changectx(rev))
+        self._deselectSamePatch(self.comboa)
+
+    def _deselectSamePatch(self, combo):
+        # if the same patch or shelve is selected by both sides, "move" action
+        # will corrupt patch content.
+        if self.currentPatchA() != self.currentPatchB():
+            return
+        if combo.count() > 1:
+            combo.setCurrentIndex((combo.currentIndex() + 1) % combo.count())
+        else:
+            combo.setCurrentIndex(-1)
 
     @pyqtSlot(int, int)
     def linkSplitters(self, pos, index):
@@ -450,11 +520,11 @@ class ShelveDialog(QDialog):
         if self.browseb.splitter.sizes()[0] != pos:
             self.browseb.splitter.moveSplitter(pos, index)
 
-    @pyqtSlot(QString)
+    @pyqtSlot(str)
     def linkActivated(self, linktext):
         pass
 
-    @pyqtSlot(QString)
+    @pyqtSlot(str)
     def showMessage(self, message):
         self.statusbar.showMessage(message)
 
@@ -470,24 +540,15 @@ class ShelveDialog(QDialog):
     def restoreSettings(self):
         s = QSettings()
         wb = "shelve/"
-        self.restoreGeometry(s.value(wb + 'geometry').toByteArray())
-        self.splitter.restoreState(s.value(wb + 'panesplitter').toByteArray())
+        self.restoreGeometry(qtlib.readByteArray(s, wb + 'geometry'))
+        self.splitter.restoreState(qtlib.readByteArray(s, wb + 'panesplitter'))
         self.browsea.splitter.restoreState(
-                          s.value(wb + 'filesplitter').toByteArray())
+            qtlib.readByteArray(s, wb + 'filesplitter'))
         self.browseb.splitter.restoreState(
-                          s.value(wb + 'filesplitter').toByteArray())
+            qtlib.readByteArray(s, wb + 'filesplitter'))
         self.browsea.loadSettings(s, wb + 'fileviewa')
         self.browseb.loadSettings(s, wb + 'fileviewb')
 
     def reject(self):
         self.storeSettings()
         super(ShelveDialog, self).reject()
-
-def run(ui, *pats, **opts):
-    if 'repo' in opts:
-        repo = opts['repo']
-    else:
-        from tortoisehg.util import paths
-        from tortoisehg.hgqt import thgrepo
-        repo = thgrepo.repository(ui, path=paths.find_root())
-    return ShelveDialog(repo)
